/*jslint nomen: true, unparam: true, indent: 2 */

/**
 * Deps
 */
var _    = require('lodash');
var path = require('path');


/**
 * Renders a template of a response
 * Returns rendered output as callback if there is
 * Otherwise sends output to response
 *
 * @param {object} req        - Express request
 * @param {object} res        - Express response
 * @param {function} callback - Callback function
 * @returns {object}          - Output response
 */
var render = function (req, res, callback) {
  "use strict";

  var route = _.get(res, 'params.route'),
    useTemplate = _.get(route, 'template'),
    templateFile = global.__MODDIR + route.name + '/view.html',
    params = res.params;


  if (!route) {
    throw new Error('Route not found!');
  }

  if (!useTemplate) {
    return res.end('NO_TEMPLATE!');
  }


  res.render(templateFile, params, function (err, out) {
    if (err) { throw new Error('SWIG_COMPILE_ERR: ' + err); }

    if (callback) { return callback(err, out); }

    return res.send(out);
  });
};


/**
 * Exports
 */
module.exports = render;