/*jslint nomen: true, indent: 2 */
/*global Router */

/**
 * Deps
 */
var _             = require('lodash');
var path          = require('path');
var RouterExpress = require('router-express');
var requireAll    = require('require-all');


/**
 * Init
 */
var router = {};


/**
 * Finds all route.js files under $modulesDir
 *   and merges them into a one single file
 *   for router-express to process easily
 *
 * @param {string} modulesDir
 * @returns {object}
 */
router.mergeRoutes = function (modulesDir) {
  "use strict";

  var libs, routes;

  libs = requireAll({
    dirname: modulesDir,
    filter: /(routes)\.js$/,
    excludeDirs :  /^\.(git|svn)$/
  });

  routes = _.flatten(
    _.reduce(libs, function (results, routesObj) {
      results.push(routesObj.routes);
      return results;
    }, [])
  );

  return routes;
};


/**
 * Binds Router to application
 *
 * @param {object} app - Express application
 */
router.bindRoutes = function (app) {
  "use strict";

  var modulesDir = path.join(__dirname, '../modules'),
    routes       = router.mergeRoutes(modulesDir);

  global.Router = new RouterExpress(routes, modulesDir);

  Router.bind(app);
};


/**
 * Binds not found / default fallback action
 *
 * @param {object} app - Express application
 */
router.bindNotFound = function (app) {
  "use strict";

  app.use(function (req, res) {
    if (!req) { req = {}; }

    res.end('NOT_FOUND');
  });
};


/**
 * Exports
 */
module.exports = router;