/*jslint nomen: true, indent: 2*/

/**
 * Deps
 */
var conf = require('./lib/conf');


/**
 * Config
 */
var cores    = parseInt(conf('SERVER_CORES') || 1,    10);
var port     = parseInt(conf('SERVER_PORT')  || 3000, 10);
var portMode = conf('SERVER_PORTMODE') || 'same';


/**
 * Serves and listens the application
 *
 * @param {integer} port
 */
var startInstance = function (port) {
  "use strict";

  var app  = require('./app'),
    http   = require('http'),
    server = http.createServer(app);

  server.listen(port, function () {
    console.log('Server listening on ' + port);
  });
};


/**
 * Starts server
 * If number of cores is 1, starts one instance only
 * If not, then starts cluster and forks process as needed
 *
 * @returns {function} - App instance
 */
var startServer = function () {
  "use strict";

  // Single thread
  if (cores === 1) {
    return startInstance(port);
  }

  // Multi thread
  var cluster = require('cluster'),
    workerId,
    workerPort,
    i;

  if (cluster.isMaster) {
    console.log('Cluster master started.');

    for (i = 0; i < cores; i += 1) {
      cluster.fork();
    }
  } else {
    workerId = parseInt(cluster.worker.id, 10);
    workerPort = portMode === 'increment' ? port + workerId - 1 : port;

    console.log('Cluster worker ' + cluster.worker.id + ' started');

    return startInstance(workerPort);
  }
};


/**
 * Start server on file execute
 */
startServer();